# Changelog

## 0.1.1 (2026-03-11)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/revoxai/revox-python/compare/v0.1.0...v0.1.1)

### Chores

* update SDK settings ([4233199](https://github.com/revoxai/revox-python/commit/42331998b9be41c9aefd4a966db67f136b8bc929))
* update SDK settings ([3692027](https://github.com/revoxai/revox-python/commit/3692027154764a581c6cb8976f37ab5eed0b009b))

## 0.1.0 (2026-03-11)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/revoxai/revox-python/compare/v0.0.3...v0.1.0)

### Features

* **api:** api update ([47814a0](https://github.com/revoxai/revox-python/commit/47814a0abb1dddb9e3d3d18c8144c9b9d222bf44))
* **api:** api update ([161edce](https://github.com/revoxai/revox-python/commit/161edcebdb5b3c283f78c544106eae5cf4051348))
* **api:** manual updates ([e803704](https://github.com/revoxai/revox-python/commit/e8037049981eb8eb4388f3bbe5fb3cd563fd040e))


### Chores

* **ci:** bump uv version ([95b4dca](https://github.com/revoxai/revox-python/commit/95b4dca2290243e61db34d3a3533ba2c0177701c))
* **ci:** skip uploading artifacts on stainless-internal branches ([5a9bf9c](https://github.com/revoxai/revox-python/commit/5a9bf9cfa470677aacb2570c54605d8a39e091e7))
* configure new SDK language ([65d1936](https://github.com/revoxai/revox-python/commit/65d19367c5d8268715a58a7e5402e1b49ca89fdf))
* **internal:** add request options to SSE classes ([6d05a10](https://github.com/revoxai/revox-python/commit/6d05a10057d5d6d48a85a4c3d97f8bc2b1b83800))
* **internal:** make `test_proxy_environment_variables` more resilient ([138344e](https://github.com/revoxai/revox-python/commit/138344efcb59e61317c8c8127a083a243fbe61bb))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([30fcd9a](https://github.com/revoxai/revox-python/commit/30fcd9ad67d38a701fd10337874f8e3e43ff87c9))
* **internal:** refactor authentication internals ([47f48c9](https://github.com/revoxai/revox-python/commit/47f48c9afa6c132a89139aa8450bd9f333e53dbc))
* update SDK settings ([d2dc52b](https://github.com/revoxai/revox-python/commit/d2dc52bd7134fe25059c0ab9111b090e217dd96a))
* update SDK settings ([6601308](https://github.com/revoxai/revox-python/commit/6601308e843883f7bc8668dd4bae645b83ca4b50))
* update SDK settings ([7c78020](https://github.com/revoxai/revox-python/commit/7c78020b1680b6c58cd7cf278baca57831426a01))

## 0.0.3 (2026-02-20)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/revoxai/revox-python/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([e330542](https://github.com/revoxai/revox-python/commit/e330542311ec2ad25ce4ffd8bce90a6fb59669be))
* update SDK settings ([bfa1341](https://github.com/revoxai/revox-python/commit/bfa134107abb388964210f3ab4e249f7a32d09ce))
* update SDK settings ([7589b81](https://github.com/revoxai/revox-python/commit/7589b81319d38b04d6c724fc21e476e057846f83))

## 0.0.2 (2026-02-20)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/revoxai/revox-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([01b1cc7](https://github.com/revoxai/revox-python/commit/01b1cc7f27c022f32dc456e6c869546dc0486bc0))
* update SDK settings ([fb013a4](https://github.com/revoxai/revox-python/commit/fb013a4c8762720a500b41ab42e90aa25c9c28d2))
* update SDK settings ([2e58195](https://github.com/revoxai/revox-python/commit/2e58195a2c5a74837ec61bf984e0611e403f9c63))
